=========
Changelog
=========

Version 0.X (unreleased)
========================

-

Version 0.1.2
=============

- Update pyscaffold structure
- Add automatic pypi deploy
- Add option to remove time zone info from time series

Version 0.1.1
=============

- Contains extended time series reader

Version 0.1
===========

- Add smecv grid support
- Add reader from images and image stacks
- Add reshuffle module
- Add first version of metadata module
- Add basic documentation
- Add unit tests for all modules
